"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExportConnectionsModal = void 0;
const react_1 = __importStar(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const file_input_1 = require("./file-input");
const passphrase_1 = require("./passphrase");
const select_table_1 = require("./select-table");
const common_1 = require("../hooks/common");
const use_export_connections_1 = require("../hooks/use-export-connections");
const provider_1 = require("compass-preferences-model/provider");
const TOAST_TIMEOUT_MS = 5000;
const tableStyles = (0, compass_components_1.css)({
    maxHeight: '24vh',
    overflow: 'auto',
});
const selectTableColumns = [['name', 'Connection Name']];
function ExportConnectionsModal({ open, setOpen, afterExport, trackingProps, }) {
    const { openToast } = (0, compass_components_1.useToast)('compass-connection-import-export');
    const finish = (0, react_1.useCallback)((result) => {
        setOpen(false);
        if (result === 'succeeded') {
            openToast('export-succeeded', {
                title: 'Export successful',
                description: 'Connections successfully exported',
                variant: 'success',
                timeout: TOAST_TIMEOUT_MS,
            });
            afterExport?.();
        }
    }, [afterExport, openToast, setOpen]);
    const openModalThroughIpc = (0, react_1.useCallback)(() => {
        setOpen(true, { context: 'menuBar' });
    }, [setOpen]);
    (0, common_1.useOpenModalThroughIpc)(open, openModalThroughIpc, 'compass:open-export-connections');
    const protectConnectionStrings = !!(0, provider_1.usePreference)('protectConnectionStrings');
    const { onSubmit, onCancel, onChangeFilename, onChangePassphrase, onChangeConnectionList, onChangeRemoveSecrets, state: { inProgress, error, connectionList, filename, removeSecrets, passphrase, }, } = (0, use_export_connections_1.useExportConnections)({
        finish,
        open,
        trackingProps,
    });
    return (react_1.default.createElement(compass_components_1.FormModal, { open: open, onCancel: onCancel, onSubmit: onSubmit, title: "Export saved connections", submitButtonText: "Export", submitDisabled: inProgress ||
            !!error ||
            !filename ||
            connectionList.every((item) => !item.selected), "data-testid": "connection-export-modal" },
        react_1.default.createElement(select_table_1.SelectTable, { className: tableStyles, items: connectionList, columns: selectTableColumns, disabled: inProgress, onChange: onChangeConnectionList }),
        react_1.default.createElement(compass_components_1.FormFieldContainer, null,
            react_1.default.createElement(file_input_1.FileInput, { label: "Target File", mode: "save", disabled: inProgress, onChange: onChangeFilename, value: filename })),
        react_1.default.createElement(compass_components_1.FormFieldContainer, null,
            react_1.default.createElement(compass_components_1.Checkbox, { checked: removeSecrets, disabled: inProgress || protectConnectionStrings, label: "Remove Secrets", description: "Omit secrets such as passwords and access tokens", onChange: onChangeRemoveSecrets, "data-testid": "connection-export-remove-secrets" })),
        react_1.default.createElement(compass_components_1.FormFieldContainer, null,
            react_1.default.createElement(passphrase_1.Passphrase, { label: "Encryption Password", description: "Optional passphrase to encrypt secrets such as passwords and access tokens", required: false, disabled: inProgress || removeSecrets, onChange: onChangePassphrase, value: passphrase })),
        error && react_1.default.createElement(compass_components_1.Banner, { variant: "danger" },
            "Error: ",
            error)));
}
exports.ExportConnectionsModal = ExportConnectionsModal;
//# sourceMappingURL=export-modal.js.map